@@ -61,7 +61,7 @@ typedef IO OIO;
 #  endif
 #endif
 
-#ifdef aTHX // define class member helpers for storing perl interpreter
+#ifdef PERL_IMPLICIT_CONTEXT // define class member helpers for storing perl interpreter
 #  define mTHX      pTHX;
 #  define mTHXa(a)  aTHX(a),
 #else
